@@ -29,6 +29,7 @@ const (
 	ScriptFailure       JobFailureReason = "script_failure"
 	RunnerSystemFailure JobFailureReason = "runner_system_failure"
 	JobExecutionTimeout JobFailureReason = "job_execution_timeout"
+	UnknownFailure      JobFailureReason = "unknown_failure"
 	// JobCanceled is only internal to runner, and not used inside of rails.
 	JobCanceled JobFailureReason = "job_canceled"
 )
@@ -90,6 +91,10 @@ type FeaturesInfo struct {
 	ReturnExitCode          bool `json:"return_exit_code"`
 }
 
+type ConfigInfo struct {
+	Gpus string `json:"gpus"`
+}
+
 type RegisterRunnerParameters struct {
 	Description    string `json:"description,omitempty"`
 	Tags           string `json:"tag_list,omitempty"`
@@ -127,6 +132,7 @@ type VersionInfo struct {
 	Executor     string       `json:"executor,omitempty"`
 	Shell        string       `json:"shell,omitempty"`
 	Features     FeaturesInfo `json:"features"`
+	Config       ConfigInfo   `json:"config,omitempty"`
 }
 
 type JobRequest struct {
@@ -331,7 +337,8 @@ type Dependency struct {
 type Dependencies []Dependency
 
 type GitlabFeatures struct {
-	TraceSections bool `json:"trace_sections"`
+	TraceSections  bool               `json:"trace_sections"`
+	FailureReasons []JobFailureReason `json:"failure_reasons"`
 }
 
 type JobResponse struct {
