@@ -55,7 +55,11 @@ func (s *commandExecutor) Connect() (terminalsession.Conn, error) {
 	// `gitlab-terminal` package. There are plans to improve this please take a
 	// look at https://gitlab.com/gitlab-org/gitlab-ce/issues/50384#proposal and
 	// https://gitlab.com/gitlab-org/gitlab-terminal/issues/4
-	containerID, err := s.watchForRunningBuildContainer(time.Now().Add(waitForContainerTimeout))
+	timeout := s.terminalWaitForContainerTimeout
+	if timeout == 0 {
+		timeout = waitForContainerTimeout
+	}
+	containerID, err := s.watchForRunningBuildContainer(time.Now().Add(timeout))
 	if err != nil {
 		return nil, err
 	}
