@@ -1,13 +1,18 @@
+// +build integration
+
 package kubernetes_test
 
 import (
 	"bytes"
 	"context"
 	"fmt"
+	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
 	"net/url"
 	"os"
+	"regexp"
+	"strings"
 	"testing"
 	"time"
 
@@ -26,6 +31,7 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 	"gitlab.com/gitlab-org/gitlab-runner/session"
+	"gitlab.com/gitlab-org/gitlab-runner/shells"
 )
 
 type featureFlagTest func(t *testing.T, flagName string, flagValue bool)
@@ -54,6 +60,7 @@ func TestRunIntegrationTestsWithFeatureFlag(t *testing.T) {
 		"testKubernetesWithNonRootSecurityContext":                testKubernetesWithNonRootSecurityContext,
 		"testConfiguredBuildDirVolumeMountFeatureFlag":            testBuildDirVolumeMountFeatureFlag,
 		"testUserConfiguredBuildDirVolumeMountFeatureFlag":        testUserConfiguredBuildDirVolumeMountFeatureFlag,
+		"testKubernetesPwshFeatureFlag":                           testKubernetesPwshFeatureFlag,
 	}
 
 	featureFlags := []string{
@@ -430,7 +437,7 @@ func testInteractiveTerminalFeatureFlag(t *testing.T, featureFlagName string, fe
 	}
 
 	client := getTestKubeClusterClient(t)
-	secrets, err := client.CoreV1().Secrets("default").List(metav1.ListOptions{})
+	secrets, err := client.CoreV1().Secrets("default").List(context.Background(), metav1.ListOptions{})
 	require.NoError(t, err)
 
 	build := getTestBuild(t, func() (common.JobResponse, error) {
@@ -560,6 +567,88 @@ func testUserConfiguredBuildDirVolumeMountFeatureFlag(t *testing.T, featureFlagN
 	assert.NoError(t, err)
 }
 
+// TestLogDeletionAttach tests the outcome when the log files are all deleted
+func TestLogDeletionAttach(t *testing.T) {
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
+
+	t.Skip("Log deletion test temporary skipped: issue https://gitlab.com/gitlab-org/gitlab-runner/-/issues/27755")
+
+	tests := []struct {
+		stage            string
+		outputAssertions func(t *testing.T, out string, pod string)
+	}{
+		{
+			stage: "step_", // Any script the user defined
+			outputAssertions: func(t *testing.T, out string, pod string) {
+				assert.Contains(
+					t,
+					out,
+					"ERROR: Job failed: command terminated with exit code 100",
+				)
+			},
+		},
+		{
+			stage: string(common.BuildStagePrepare),
+			outputAssertions: func(t *testing.T, out string, pod string) {
+				assert.Contains(
+					t,
+					out,
+					"ERROR: Job failed: command terminated with exit code 100",
+				)
+			},
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.stage, func(t *testing.T) {
+			build := getTestBuild(t, func() (common.JobResponse, error) {
+				return common.GetRemoteBuildResponse(
+					"sleep 5000",
+				)
+			})
+			buildtest.SetBuildFeatureFlag(build, featureflags.UseLegacyKubernetesExecutionStrategy, false)
+
+			deletedPodNameCh := make(chan string)
+			defer buildtest.OnUserStage(build, func() {
+				client := getTestKubeClusterClient(t)
+				pods, err := client.
+					CoreV1().
+					Pods("default").
+					List(context.Background(), metav1.ListOptions{
+						LabelSelector: labels.Set(build.Runner.Kubernetes.PodLabels).String(),
+					})
+				require.NoError(t, err)
+				require.NotEmpty(t, pods.Items)
+				pod := pods.Items[0]
+				config, err := kubernetes.GetKubeClientConfig(new(common.KubernetesConfig))
+				require.NoError(t, err)
+				logsPath := fmt.Sprintf("/logs-%d-%d", build.JobInfo.ProjectID, build.JobResponse.ID)
+				opts := kubernetes.ExecOptions{
+					Namespace: pod.Namespace,
+					PodName:   pod.Name,
+					Client:    client,
+					Stdin:     true,
+					In:        strings.NewReader(fmt.Sprintf("rm -rf %s/*", logsPath)),
+					Out:       ioutil.Discard,
+					Command:   []string{"/bin/sh"},
+					Config:    config,
+					Executor:  &kubernetes.DefaultRemoteExecutor{},
+				}
+				err = opts.Run()
+				require.NoError(t, err)
+
+				deletedPodNameCh <- pod.Name
+			})()
+
+			out, err := buildtest.RunBuildReturningOutput(t, build)
+			require.Error(t, err)
+			assert.True(t, err != nil, "No error returned")
+
+			tt.outputAssertions(t, out, <-deletedPodNameCh)
+		})
+	}
+}
+
 // This test reproduces the bug reported in https://gitlab.com/gitlab-org/gitlab-runner/issues/2583
 func TestPrepareIssue2583(t *testing.T) {
 	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
@@ -591,6 +680,7 @@ func TestPrepareIssue2583(t *testing.T) {
 
 	e := kubernetes.NewDefaultExecutorForTest()
 
+	// TODO: handle the context properly with https://gitlab.com/gitlab-org/gitlab-runner/-/issues/27932
 	prepareOptions := common.ExecutorPrepareOptions{
 		Config:  runnerConfig,
 		Build:   build,
@@ -675,25 +765,31 @@ func TestDeletedPodSystemFailureDuringExecution(t *testing.T) {
 			// It's not possible to get this kind of information on the legacy execution path.
 			buildtest.SetBuildFeatureFlag(build, featureflags.UseLegacyKubernetesExecutionStrategy, false)
 
-			deletedPodCh := make(chan string)
+			deletedPodNameCh := make(chan string)
 			defer buildtest.OnStage(build, tt.stage, func() {
 				client := getTestKubeClusterClient(t)
-				pods, err := client.CoreV1().Pods("default").List(metav1.ListOptions{
-					LabelSelector: labels.Set(build.Runner.Kubernetes.PodLabels).String(),
-				})
+				pods, err := client.CoreV1().Pods("default").List(
+					context.Background(),
+					metav1.ListOptions{
+						LabelSelector: labels.Set(build.Runner.Kubernetes.PodLabels).String(),
+					},
+				)
 				require.NoError(t, err)
 				require.NotEmpty(t, pods.Items)
 				pod := pods.Items[0]
-				err = client.CoreV1().Pods("default").Delete(pod.Name, &metav1.DeleteOptions{})
+				err = client.
+					CoreV1().
+					Pods("default").
+					Delete(context.Background(), pod.Name, metav1.DeleteOptions{})
 				require.NoError(t, err)
 
-				deletedPodCh <- pod.Name
+				deletedPodNameCh <- pod.Name
 			})()
 
 			out, err := buildtest.RunBuildReturningOutput(t, build)
 			assert.True(t, kubernetes.IsKubernetesPodNotFoundError(err), "expected err NotFound, but got %T", err)
 
-			tt.outputAssertions(t, out, <-deletedPodCh)
+			tt.outputAssertions(t, out, <-deletedPodNameCh)
 		})
 	}
 }
@@ -720,6 +816,28 @@ func testKubernetesWithNonRootSecurityContext(t *testing.T, featureFlagName stri
 	assert.Contains(t, out, fmt.Sprintf("uid=%d gid=0(root)", runAsUser))
 }
 
+func testKubernetesPwshFeatureFlag(t *testing.T, featureFlagName string, featureFlagValue bool) {
+	helpers.SkipIntegrationTests(t, "kubectl", "cluster-info")
+
+	build := getTestBuild(t, common.GetRemoteSuccessfulBuild)
+	buildtest.SetBuildFeatureFlag(build, featureFlagName, featureFlagValue)
+
+	build.Image.Name = common.TestPwshImage
+	build.Runner.Shell = shells.SNPwsh
+	build.JobResponse.Steps = common.Steps{
+		common.Step{
+			Name: common.StepNameScript,
+			Script: []string{
+				"Write-Output $PSVersionTable",
+			},
+		},
+	}
+
+	out, err := buildtest.RunBuildReturningOutput(t, build)
+	assert.NoError(t, err)
+	assert.Regexp(t, regexp.MustCompile("PSEdition +Core"), out)
+}
+
 func getTestBuild(t *testing.T, getJobResponse func() (common.JobResponse, error)) *common.Build {
 	jobResponse, err := getJobResponse()
 	assert.NoError(t, err)
