@@ -111,7 +111,7 @@ func (s *executor) createVM(vmName string) (err error) {
 			s.Debugln("Creating testing VM from VM", baseImage, "snapshot", baseSnapshot, "...")
 		}
 
-		err = vbox.CreateOsVM(baseImage, vmName, baseSnapshot)
+		err = vbox.CreateOsVM(baseImage, vmName, baseSnapshot, s.Config.VirtualBox.BaseFolder)
 		if err != nil {
 			return err
 		}
@@ -318,8 +318,9 @@ func (s *executor) Run(cmd common.ExecutorCommand) error {
 		Command:     s.BuildShell.GetCommandWithArguments(),
 		Stdin:       cmd.Script,
 	})
-	if _, ok := err.(*ssh.ExitError); ok {
-		err = &common.BuildError{Inner: err}
+	if exitError, ok := err.(*ssh.ExitError); ok {
+		exitCode := exitError.ExitCode()
+		err = &common.BuildError{Inner: err, ExitCode: exitCode}
 	}
 	return err
 }
