@@ -8,8 +8,6 @@ import (
 
 const (
 	baseImage1809 = "servercore1809"
-	baseImage1903 = "servercore1903"
-	baseImage1909 = "servercore1909"
 	baseImage2004 = "servercore2004"
 
 	windowsSupportedArchitecture = "x86_64"
@@ -17,8 +15,6 @@ const (
 
 var helperImages = map[string]string{
 	windows.V1809: baseImage1809,
-	windows.V1903: baseImage1903,
-	windows.V1909: baseImage1909,
 	windows.V2004: baseImage2004,
 }
 
