@@ -1,3 +1,5 @@
+// +build !integration
+
 package windows
 
 import (
@@ -22,16 +24,6 @@ func TestVersion(t *testing.T) {
 			expectedVersion: V1809,
 			expectedErr:     nil,
 		},
-		{
-			operatingSystem: "Windows Server Datacenter Version 1903 (OS Build 18362.592)",
-			expectedVersion: V1903,
-			expectedErr:     nil,
-		},
-		{
-			operatingSystem: "Windows Server Datacenter Version 1909 (OS Build 18363.720)",
-			expectedVersion: V1909,
-			expectedErr:     nil,
-		},
 		{
 			operatingSystem: "Windows 10 Pro Version 2004 (OS Build 19041.329)",
 			expectedVersion: V2004,
