@@ -12,9 +12,6 @@ const (
 	UseLegacyKubernetesExecutionStrategy        string = "FF_USE_LEGACY_KUBERNETES_EXECUTION_STRATEGY"
 	UseDirectDownload                           string = "FF_USE_DIRECT_DOWNLOAD"
 	SkipNoOpBuildStages                         string = "FF_SKIP_NOOP_BUILD_STAGES"
-	ShellExecutorUseLegacyProcessKill           string = "FF_SHELL_EXECUTOR_USE_LEGACY_PROCESS_KILL"
-	ResetHelperImageEntrypoint                  string = "FF_RESET_HELPER_IMAGE_ENTRYPOINT"
-	UseGoCloudWithCacheArchiver                 string = "FF_USE_GO_CLOUD_WITH_CACHE_ARCHIVER"
 	UseFastzip                                  string = "FF_USE_FASTZIP"
 	GitLabRegistryHelperImage                   string = "FF_GITLAB_REGISTRY_HELPER_IMAGE"
 	DisableUmaskForDockerExecutor               string = "FF_DISABLE_UMASK_FOR_DOCKER_EXECUTOR"
@@ -57,7 +54,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            UseLegacyKubernetesExecutionStrategy,
-		DefaultValue:    true,
+		DefaultValue:    false,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "When set to `false` disables execution of remote Kubernetes commands through `exec` in " +
@@ -81,31 +78,6 @@ var flags = []FeatureFlag{
 		ToBeRemovedWith: "",
 		Description:     "When set to `false` all build stages are executed even if running them has no effect",
 	},
-	{
-		Name:            ShellExecutorUseLegacyProcessKill,
-		DefaultValue:    false,
-		Deprecated:      true,
-		ToBeRemovedWith: "14.0",
-		Description: "Use the old process termination that was used prior to GitLab 13.1 where only `SIGKILL`" +
-			" was sent",
-	},
-	{
-		Name:            ResetHelperImageEntrypoint,
-		DefaultValue:    true,
-		Deprecated:      true,
-		ToBeRemovedWith: "14.0",
-		Description: "Enables adding an ENTRYPOINT layer for Helper images imported from local Docker archives " +
-			"by the `docker` executor, in order to enable [importing of user certificate roots]" +
-			"(tls-self-signed.md#trusting-the-certificate-for-the-other-cicd-stages)",
-	},
-	{
-		Name:            UseGoCloudWithCacheArchiver,
-		DefaultValue:    true,
-		Deprecated:      true,
-		ToBeRemovedWith: "14.0",
-		Description: "Enables the use of Go Cloud to write cache archives to object storage. " +
-			"This mode is only used by Azure Blob storage.",
-	},
 	{
 		Name:            UseFastzip,
 		DefaultValue:    false,
@@ -115,7 +87,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:            GitLabRegistryHelperImage,
-		DefaultValue:    false,
+		DefaultValue:    true,
 		Deprecated:      false,
 		ToBeRemovedWith: "",
 		Description: "Use GitLab Runner helper image for the Docker and " +
