@@ -18,12 +18,13 @@ const (
 	endPlaceholder   = "<!-- feature_flags_list_end -->"
 )
 
+//nolint:lll
 var ffTableTemplate = `{{ placeholder "start" }}
 
 | Feature flag | Default value | Deprecated | To be removed with | Description |
 |--------------|---------------|------------|--------------------|-------------|
 {{ range $_, $flag := . -}}
-| {{ $flag.Name | raw }} | {{ $flag.DefaultValue | raw }} | {{ $flag.Deprecated | tick }} | {{ $flag.ToBeRemovedWith }} | {{ $flag.Description }} |
+| {{ $flag.Name | raw }} | {{ $flag.DefaultValue | bool }} | {{ $flag.Deprecated | tick }} | {{ $flag.ToBeRemovedWith }} | {{ $flag.Description }} |
 {{ end }}
 {{ placeholder "end" }}
 `
@@ -62,6 +63,9 @@ func prepareTable() string {
 		"raw": func(input string) string {
 			return fmt.Sprintf("`%s`", input)
 		},
+		"bool": func(input bool) string {
+			return fmt.Sprintf("`%t`", input)
+		},
 		"tick": func(input bool) string {
 			if input {
 				return "✓"
@@ -86,7 +90,7 @@ func prepareTable() string {
 	return buffer.String()
 }
 
-func replace(fileContent string, tableContent string) string {
+func replace(fileContent, tableContent string) string {
 	replacer := newBlockLineReplacer(startPlaceholder, endPlaceholder, fileContent, tableContent)
 
 	newContent, err := replacer.Replace()
@@ -164,7 +168,7 @@ func (r *blockLineReplacer) handleEnd(line string) {
 	r.output.WriteString(r.replaceContent)
 }
 
-func newBlockLineReplacer(startLine string, endLine string, input string, replaceContent string) *blockLineReplacer {
+func newBlockLineReplacer(startLine, endLine string, input, replaceContent string) *blockLineReplacer {
 	return &blockLineReplacer{
 		startLine:      startLine,
 		endLine:        endLine,
